candv: Constants & Values
=========================

|Build Status| |Coverage Status|
|PyPi package| |PyPi downloads| |Docs| |License|

This is a little Python library which provides an easy way for creating complex
constants.

Inspired by `Constants from Twisted`_ and `Django form fields`_.

Please, `read the docs`_ for more information.

.. |Build Status| image:: http://img.shields.io/travis/oblalex/candv.svg?branch=master&style=flat
   :target: https://travis-ci.org/oblalex/candv
.. |Coverage Status| image:: http://img.shields.io/coveralls/oblalex/candv.svg?branch=master&style=flat
   :target: https://coveralls.io/r/oblalex/candv?branch=master
.. |PyPi package| image:: http://img.shields.io/pypi/v/candv.svg?style=flat
   :target: http://badge.fury.io/py/candv/
.. |PyPi downloads| image:: http://img.shields.io/pypi/dm/candv.svg?style=flat
   :target: https://crate.io/packages/candv/
.. |Docs| image:: https://readthedocs.org/projects/candv/badge/?version=latest&style=flat
   :target: `read the docs`_
.. |License| image:: https://img.shields.io/badge/license-LGPLv3-brightgreen.svg?style=flat

.. _Constants from Twisted: http://twistedmatrix.com/documents/current/core/howto/constants.html
.. _Django form fields: https://docs.djangoproject.com/en/1.6/ref/forms/fields/
.. _read the docs: http://candv.readthedocs.org/en/latest/
